.\" bm# 0000002089
.\" typ N
.\" ver generic
.\" mod generic
.\"
.\"     SCCSID(@(#)fsck.C	1.1);


.ds mc 
.ds rv Revision 1
.TH FSCK C
.SH Name
fsck \- Checks and repairs file systems.
.SH Syntax
.B /etc/fsck
[ options ] [ file-system ] ...
.SH Description
.I  Fsck\^
audits and interactively repairs inconsistent conditions for 
.SM XENIX
file systems, whether 
.SM XENIX
version 2.3 or 3.0. 
If the file system is consistent 
then the number of files, number of blocks
used, and number of blocks free are reported.
If the file system is inconsistent the 
operator is prompted for concurrence
before each correction is attempted.
It should be noted that most corrective actions 
result in some loss of data.
The amount and severity of the loss may be determined 
from the diagnostic output.
The default action for each consistency correction
is to wait for the operator to respond ``yes'' or ``no''.
If the operator does not have write permission 
.I fsck\^
defaults to the  action of the
.B \-n 
option.
.PP
The following flags are interpreted by
.IR fsck :
.TP 6
.B  \-y
Assumes a yes response to all questions asked by 
.IR fsck .
.TP 6
.B  \-n
Assumes a no response to all questions asked by 
.IR fsck ;
do not open the file system for writing.
.TP 6
.BR \-s \fIb\^\fR:\fIc\fR
Ignores the actual free list and (unconditionally) reconstructs a new
one by rewriting the super-block of the file system.  
The file system 
.I must 
be unmounted while this is done.
.IP
The
.BR \-s \fIb\^\fR:\fIc\fR:c 
option allows for creating an optimal free-list organization.
The following forms are supported:
.sp
.nf
'\"	\-s3 (\s-1RP\s+1\&03)
'\"	\-s4 (\s-1RP\s+1\&04, \s-1RP\s+1\&05, \s-1RP\s+1\&06)
	\-s
	\-sBlocks-per-cylinder\fB:\fRBlocks-to-skip (for anything else)
.fi
.IP "" 6
If \fIb\^\fR:\fIc\fR
is not given, then the values used 
when the file system was created are used.
If these values were not specified, 
then a reasonable default value is used.
.TP 6
.BR \-S 
Conditionally reconstructs the free list. This option
is like
.BR \-s \fIb\^\fR:\fIc\fR
above except that the free list is rebuilt only
if there are no discrepancies discovered in the
file system. Using
.B \-S
forces a ``no'' response to all questions asked by
.IR fsck .
This option is useful for forcing free list reorganization
on uncontaminated file systems.
.TP 6
.B \-t
If
.I fsck\^
cannot obtain enough memory to keep its tables,
it uses a scratch file. 
If the 
.B \-t
option is specified, the file named in the next argument
is used as the scratch file, if needed. 
Without the
.BR "\-t " flag,
.I fsck\^
prompts the operator for the name of the
scratch file. 
The file chosen should not be on the
file system being checked, and if it is not
a special file or did not already exist, it is
removed when
.I fsck\^
completes.
.TP 6
.B \-rr
Recovers the root file system.
The required 
.I filesystem
argument must refer to the root file system,
and preferably to the block device (normally 
.B /dev/root .)
This switch implies 
.B \-y
and overrides 
.B \-n .
If any modifications to the file system are required,
the system will be automatically shutdown 
to insure the integrity of the file system.
.TP 6
.B \-c
Causes any supported file system to be converted to the
type of the current file system. The user is asked to verify
the request for each file system that requires conversion
unless the
.B \-y
option is specified.
It is recommended that every file system be checked with
this option,
.I "while unmounted"
if it is to be used with the current version of
.SM XENIX.
To update the active root file system, it should be checked with:
.in +5
.sp
fsck\ \-c\ \-rr\ /dev/root
.in -5
.PP
If no
.I file
.I systems\^
are specified,
.I fsck\^
reads a list of default file systems from
the file
.BR /etc/checklist .
.PP
.ne 10
Inconsistencies checked are as follows:
.TP  
\- 
Blocks claimed by more than one inode or the free list
.TP 
\- 
Blocks claimed by an inode or the free list outside the 
range of the file system
.TP 
\-
Incorrect link counts
.TP  
\-
Size checks:
.br
.ns
.IP "" 6
Incorrect number of blocks
.br
Directory size not 16-byte aligned
.TP 2
\-
Bad inode format
.TP 2  
\-
Blocks not accounted for anywhere
.br
.TP 2
\-
Directory checks:
.br
.ns
.IP "" 6
File pointing to unallocated inode
.br
Inode number out of range
.br
.br
.TP 2
\-
Super-block checks:
.br
.br
.ns
.IP "" 6
More than 65536 inodes
.br
More blocks for inodes than there are in the file system
.br
.TP 2
\-
Bad free block list format
.TP 2
\-
Total free block or free inode count incorrect
.PP
Orphaned files and directories (allocated but unreferenced) are,
with the operator's concurrence, reconnected by
placing them in the 
.B lost+found
directory.
The name assigned is the inode number.
The only restriction
is that the directory 
.B lost+found
must preexist
in the root of the file system being checked and
must have empty slots in which entries can be made.
This is accomplished by making 
.BR lost+found ,
copying a number of files to the directory, and then removing them
(before
.I
fsck
is executed).
.SH Files
.br
.ns
.TP 16
/etc/checklist
Contains default list of file systems to check
.SH "See Also"
checklist(F), filesystem(F)
.SH Diagnostics
The diagnostics produced by 
.I fsck\^
are intended to be self-explanatory.
.SH Notes
.I Fsck\^
will not run on a 
.I mounted
non-raw file system unless the file system is the root
file system or unless the 
.B \-n 
option is specified and no writing out of the file system
will take place..
If any such attempt is made, a warning is printed and no further
processing of the file system is done for the specified device.
.PP
Although
checking a raw device is almost always faster,
there is no way to tell if the file system is mounted.
And cleaning a mounted file system will almost certainly
result in an inconsistent superblock. 
.SH Warning
For a 
.SM XENIX
2.3 file system to be properly supported under
.SM XENIX
3.0, it is necessary that 
.I fsck
be run on each 2.3 file system to be mounted under the
.SM XENIX
3.0 kernel.
For the root file system, 
``fsck\0\-rr\0/dev/root'' should be run 
and for all other file systems
``fsck\0/dev/??'' on the 
.I unmounted 
block device should be used.
