.\" bm# 0000002087
.\" typ N
.\" ver generic
.\" mod generic
.\"
.\"     SCCSID(@(#)grep.C	1.1);


.ds mc 
.ds rv Revision 1
.TH GREP C
.SH Name
grep, egrep, fgrep \- Searches a file for a pattern.
.SH Syntax
.B grep
[ options ] expression [ files ]
.PP
.B egrep
[ options ] [ expression ] [ files ]
.PP
.B fgrep
[ options ] [ strings ] [ files ]
.SH Description
Commands of the
.I grep\^
family search the input
.I files\^
(standard input default)
for lines matching
a pattern.
Normally, each line found
is copied to the standard output.
.I Grep\^
patterns are limited regular
.IR expression s
in the style of
.IR ed (C);
it uses a compact nondeterministic algorithm.
.I Egrep\^
patterns are full regular
.IR expression s;
it
uses a fast deterministic algorithm that
sometimes needs exponential space.
.I Fgrep\^
patterns are fixed
.IR strings ;
it
is fast and compact.
The following
.I options\^
are recognized:
.PP
.TP 6
.B \-v
All lines but those matching
are printed.
.TP
.B \-x
Prints only exact matches of an entire line.
.RI ( Fgrep 
only.)
.TP
.B \-c
Only a count of matching lines is printed.
.TP
.B \-l
Only the names of files with matching lines are listed,
separated by newlines.
.TP
.B \-n
Each line is preceded by
its relative line number in the file.
.TP
.B \-b
Each line is preceded by the block number
on which it was found.
This is sometimes useful in locating
disk block numbers by context.
.TP
.B \-s
Suppresses error messages produced for
nonexistent or unreadable files.
.TP
.B \-y
Turns on matching of letters of either case in the input
so that case is insignificant.
Does not work for 
.I egrep.
.TP
.BI \-e " expression\^"
Same as a simple
.I expression\^
argument,
but useful when the
.I expression\^
begins with a dash
.RB ( \- ).
.TP
.BI \-f " file\^"
.br
The regular
.I expression\^
for
.I grep 
or
.IR egrep ,
or
.I strings\^
list 
(for
.IR fgrep )
is taken from the
.IR file .
.PD
.PP
In all cases, the filename is output 
if there is more than one input file.
Care should be taken when
using the characters
.BR $ ,
.BR * ,
.BR [ ,
.BR ^ ,
.BR |\|,
.BR ( ,
.BR ) ,
and
.B \e
in
.IR expression ,
because they are
also meaningful to the shell.
It is safest to enclose the
entire
.I expression\^
argument in single quotation marks.
.PP
.I Fgrep\^
searches for lines that contain one of the
.I strings\^
separated by newlines.
.PP
.I Egrep\^
accepts
regular
expressions
as in
.IR ed (C),
except for
.B \e(
and
.BR \e) ,
with the addition of the following:
.TP 
\-
A regular expression followed by a plus sign
.RB  ( + )
matches one or more occurrences of the regular expression.
.TP
\-
A regular expression followed by a question mark
.RB  ( ? )
matches 0 or 1 occurrences of the regular expression.
.TP
\-
Two regular expressions separated by a vertical bar
.RB ( | )
or by a newline match strings that are matched by either
regular expression.
.TP
\-
A regular expression may be enclosed in parentheses
.B (\|)
for grouping.
.PD
.PP
The order of precedence of operators is
.BR [\|\|] ,
then
.BR \(**\|?\|+ ,
then concatenation, then the backslash (\e) and the newline.
.SH "See Also"
ed(C),
sed(C),
sh(C)
.SH Diagnostics
Exit status is 0 if any matches are found,
1 if none, 2 for syntax errors or inaccessible files.
.SH Notes
Ideally there should be only one
.IR grep ,
but there isn't a single algorithm that spans a wide enough
range of space-time tradeoffs.
.PP
Lines
are limited to 256 characters;
longer lines are truncated.
.PP
.I Egrep\^
does not recognize
ranges, such as
.BR [a\-z] ,
in character classes.
.PP
When using 
.I grep 
with the 
.B \-y 
option,
the search is not made 
totally case insensitive
in character ranges specified within brackets.  
.PP
Multiple strings can be specified in 
.I fgrep\^
without using a separate strings file
by using the quoting conventions of the shell
to imbed newlines in the 
.I single
string argument.
For example, you might type the following at the
command line:
.PP
.RS
.nf
fgrep \'string1
string2
string3\' text.file
.fi
.sp 10p
.RE
.PP
Similarly, multiple strings can be specified in
.I egrep 
by doing:
.PP
.RS
.nf
egrep \'string1|string2|string3\' text.file
.fi
.sp 10p
.RE
Thus
.I egrep 
can do almost anything that 
.I grep
and
.I frep
can do.
