.\" bm# 0000002065
.\" typ N
.\" ver generic
.\" mod generic
.\"
.\"     SCCSID(@(#)more.C	1.1);


.ds mc 
.ds rv Revision 1
.TH MORE C 
.SH Name
more \- Views a file one screen full at a time.
.SH Syntax
.B more
[
.B \-cdflsur
]
[
.B \-\fIn\fP
]
[
.B +\fIlinenumber\fP 
]
[
.B +/\fIpattern\fP
] [ name ...  ]
.SH Description
This filter allows examination of a continuous text
one screen full at a time.
It normally pauses after each screen full, printing ``--More--''
at the bottom of the screen.
If the user then types a carriage return, one more line is displayed.
If the user hits the
.SM SPACE
bar, another screen full is displayed.  
Other possibilities are described below.
.PP
The command line options are:
.TP
.I \-n
An integer which is the size (in lines) of the window which
.I more
will use instead of the default.
.TP
.B \-c
.I More
draws each page by beginning at the top of the screen and erasing 
each line just before it draws on it.
This avoids scrolling the screen, making it easier to read while 
.I more 
is writing.
This option is ignored if the terminal does not have the ability
to clear to the end of a line.
.TP
.B \-d
.I More
prompts with the message ``Hit
space to continue, Rubout to abort" at the end of each screen
full.
This is useful if
.I more
is being used as a filter in some setting,
such as a class, where many users may be unsophisticated.
.TP
.B \-f
This option causes
.I more
to count logical, rather than screen lines.
That is, long lines are not folded.
This option is recommended if
.I nroff
output is being piped through
.I ul,
since the latter may generate escape sequences.
These escape sequences contain characters that would ordinarily occupy
screen positions, but that do not print when they are sent to the
terminal as part of an escape sequence.
Thus
.I more
may think that lines are longer than they actually are
and fold lines erroneously.
.TP
.B \-l
Does not treat 
.SM CNTRL-L 
(form feed) specially.
If this option is not given,
.I more
pauses after any line that contains a 
.SM CNTRL-L\*S, 
as if the end of a
screen full had been reached.
Also, if a file begins with a form feed, the screen is
cleared before the file is printed.
.TP
.B \-s
Squeezes multiple blank lines from the output, 
producing only one blank line.  
Especially helpful when viewing
.I nroff
output, this option maximizes 
the useful information present on the screen.
.TP
.B \-u
Normally,
.I more
handles underlining, such as that produced by
.I nroff
in a manner appropriate 
to the particular terminal:  
if the terminal can
perform underlining or has a stand-out mode,
.I more
outputs appropriate escape sequences 
to enable underlining or stand-out
mode for underlined information in the source file.  
The
.B \-u
option suppresses this processing.
.TP
.B \-r
Normally,
.I more
ignores control characters that it does not interpret in some way.
The
.I \-r
option causes these to be displayed as 
^C where ``C'' stands for any such character.
.TP
.B \-w
Normally,
.I more
exits when it comes to the end of its input. 
With
.I \-w
however,
.I more
prompts and waits for any key to be struck before exiting.
.TP
.B +\fIlinenumber\fP
Starts up at \fIlinenumber\fP.
.TP
.B +/\fIpattern\fP
Starts up two lines before the line containing the
regular expression \fIpattern\fP.
.PP
.I More
looks in the file
.I /etc/termcap
to determine terminal characteristics,
and to determine the default window size.
On a terminal capable of displaying 24 lines,
the default window size is 22 lines.
.PP
.I More
looks in the environment variable
.I MORE
to preset any flags desired.  
For example, if you prefer to view files using
the
.B \-c
mode of operation, the shell command
``MORE=\-c''
in the
.B .profile
file causes all invocations of
.I more 
to use this mode.
.PP
If
.I more
is reading from a file, rather than a pipe, 
then a percentage is displayed
along with the ``--More--'' prompt.
This gives the fraction of the file 
(in characters, not lines) that has been read so far.
.PP
Other sequences which may be typed when
.I more
pauses, and their effects, 
are as follows (\fIi\fP is an optional integer
argument, defaulting to 1):
.PP
.IP \fIi\|\fP<space>
Displays
.I i
more lines, (or another screen full if no argument is given).
.PP
.IP \s-1CNTRL-D\s0
Displays 11 more lines (a ``scroll'').
If
.I i
is given, then the scroll size is set to \fIi\|\fP.
.PP
.IP d
Same as 
.SM CNTRL-D.
.PP
.IP \fIi\|\fPz
Same as typing a space except that \fIi\|\fP, 
if present, becomes the new window size.
.PP
.IP \fIi\|\fPs
Skips \fIi\|\fP lines and prints a screen full of lines.
.PP
.IP \fIi\|\fPf
Skips \fIi\fP screen fulls and prints a screen full of lines.
.PP
.IP "q or Q"
Exits from
.I more.
.PP 
.IP =
Displays the current line number.
.PP
.IP v
Starts up the screen editor
.I vi
at the current line.
(Note that
.I vi
may not be available with your system.)
.PP
.IP "h or ?"
Help command; Gives a description of all the
.I more
commands.
.PP
.IP \fIi\|\fP/expr
Searches for the \fIi\|\fPth occurrence 
of the regular expression \fIexpr.\fP
If there are less than \fIi\fP occurrences of \fIexpr\|\fP,
and the input is a file (rather than a pipe),
then the position in the file remains unchanged.
Otherwise, a screen full is displayed, 
starting two lines before the place
where the expression was found.
The user's erase and kill characters may be used to edit the regular
expression.
Erasing back past the first column cancels the search command.
.PP
.IP \fIi\|\fPn
Searches for the \fIi\|\fPth occurrence 
of the last regular expression entered.
.PP
.IP '
(Single quotation mark) Goes to the point from which the last 
search started.
If no search has been performed in the current file, this command
goes back to the beginning of the file.
.PP
.IP !\fIcommand\fR
Invokes a shell with \fIcommand\|\fP. 
The characters % and ! in ``command" are replaced with the
current filename and the previous shell command respectively.
If there is no current filename, % is not expanded.
The sequences ``\\%'' and ``\\!'' are replaced by ``%'' 
and ``!'' respectively.
.PP
.IP \fIi\|\fP:n
Skips to the \fIi\|\fPth next file given in the command line
(skips to last file if n doesn't make sense).
.PP
.IP \fIi\|\fP:p
Skips to the \fIi\|\fPth previous file given in the command line.
If this command is given in the middle of printing out a
file, 
.I more
goes back to the beginning of the file. 
If \fIi\fP doesn't make sense,
.I more
skips back to the first file.
If
.I more
is not reading from a file, the bell rings and nothing else happens.
.PP
.IP :f
Displays the current filename and line number.
.PP
.IP ":q or :Q"
Exits from 
.I more
(same as q or Q).
.PP
.IP .
Repeats the previous command.
.PP
The commands take effect immediately, i.e., it is not necessary to
type a carriage return.
Up to the time when the command character itself is given,
the user may hit the line kill character to cancel the numerical
argument being formed.
In addition, the user may hit the erase character to redisplay the
\&``--More--(\fIxx\fP%)'' message.
'\"	.PP
'\"	Any time output is being sent to the terminal, the user may
'\"	hit the 
'\"	.SM QUIT
'\"	key (normally 
'\"	.SM CNTRL
'\"	\-\\).
'\"	.I More
'\"	will stop sending output, and 
'\"	display the usual ``--More--'' prompt.
'\"	The user may then enter one 
'\"	of the above commands in the normal manner.
'\"	Unfortunately, some output is lost when this is done, due to the
'\"	fact that any characters waiting in the terminal's output queue
'\"	are flushed when the quit signal occurs.
.PP
The terminal is set to
.I noecho
mode by this program so that the output can be continuous.
What you type will thus not show on your terminal, 
except for the slash (/) and exclamation (!) commands.
.PP
If the standard output is not a teletype, 
.I more
acts just like
.I cat,
except that a header is printed before each file (if there is
more than one).
.PP
.DT
A sample usage of
.I more
in previewing
.I nroff
output would be
.PP
	nroff \-ms +2 doc.n | more -s
.SH Files
.DT
/etc/termcap		Terminal data base
.PP
/usr/lib/more.help	Help file
.SH "See Also"
csh(CP), sh(C), environ(M)
.SH Credit
This utility was developed 
at the University of California at Berkeley 
and is used with permission.
.SH Notes
The 
.I vi\^ 
and 
.I \^help 
options may not be available.
.PP
Before displaying a file,
.I more
attempts to detect whether it is a non-printable binary file 
such as a directory or executable binary image. 
If 
.I more
concludes that a file is unprintable, it rightly refuses to print it. 
However, 
.I more 
cannot detect all possible kinds of non-printable files.
